use crate::{
    json_result::JsonResult,
    model::classroom_user::{ClassroomPersonCreate, ClassroomCourseRegistration},
    online_classroom::{create_user::create, get_courses::ClassroomCourse},
};
use rocket::{http::Status, serde::json::Json};
use crate::online_classroom::register_course::register_course;

#[options("/classroom/user")]
pub fn create_user_options() -> Status {
    Status::Ok
}

#[post("/classroom/user", format = "json", data = "<data>")]
pub async fn create_user(data: Json<ClassroomPersonCreate>) -> (Status, Json<JsonResult<()>>) {
    match create(&data.0).await {
        Ok(_) => return (Status::Ok, JsonResult::ok(())),
        Err(err) => return (Status::InternalServerError, JsonResult::err(err)),
    }
}

#[get("/classroom/course/<user_id>")]
pub async fn get_courses(user_id: i32) -> (Status, Json<JsonResult<Vec<ClassroomCourse>>>) {
    match crate::online_classroom::get_courses::get_courses(user_id).await {
        Ok(courses) => return (Status::Ok, JsonResult::ok(courses)),
        Err(err) => return (Status::InternalServerError, JsonResult::err(err)),
    }
}


#[post("/classroom/course/<user_id>", format = "json", data = "<data>")]
pub async fn register_course_contr(user_id: i32, data: Json<ClassroomCourseRegistration>) -> (Status, Json<JsonResult<()>>) {
    match register_course(user_id, &data.surname_first_letter, &data.courses).await {
        Ok(()) => return (Status::Ok, JsonResult::ok(())),
        Err(err) => return (Status::InternalServerError, JsonResult::err(err)),
    }
}
