import { createSignal } from "solid-js";
import { FilledCard } from "../components/FilledCard";
import { ClassroomRegistrationPreview } from "./ClassroomRegistrationPreview";
import { ClassroomSearchableSelect } from "./ClassroomSearchableSelect";
import { ClassroomCourseValue } from "../types/ClassroomCourse";

export function ClassroomRegistration() {
    const [selections, setSelections] = createSignal<Array<ClassroomCourseValue>>([]);

    return (
        <div class="h-screen overflow-y-scroll">
            <FilledCard class="border border-c-outline overflow-hidden">
                <h2 class="p-3 font-bold text-xl">Registrar cursos</h2>

                <div class="bg-c-surface p-4 h-[23rem]">
                    <ManualClassroomRegistration
                        onAdd={(x) => setSelections((s) => ([...s, x]))}
                    />
                </div>
            </FilledCard>

            <ClassroomRegistrationPreview
                selections={selections()}
                deleteRegister={(course_key) => setSelections((course) => course.filter((v) => v !== course_key))}
            />
        </div>
    );
}


function ManualClassroomRegistration(props: {onAdd: (k: ClassroomCourseValue) => void}) {
    return (
        <form>
            <p>Haz click en un curso para agregarlo</p>
            <br />

            <ClassroomSearchableSelect
                onAdd={props.onAdd}
            />
        </form>
    );
}
